# mantik - plugin for MLflow with HPC (UNICORE)

[Documentation](https://mantik-ai.gitlab.io/mantik)

Mantik allows to manage the full Machine Learning workflow on HPC by
supporting MLflow and deployment of applications to HPC.

```shell
mlflow run --backend unicore --backend-config <path to config> <path to project>
```

For a quickstart see [our documentation](https://mantik-ai.gitlab.io/mantik/quickstart.html)

Service desk email: contact-project+mantik-ai-mantik-42525397-issue-@incoming.gitlab.com

